package com.ruoyi.basicData.service;

import com.ruoyi.basicData.domain.TFees;
import com.ruoyi.basicData.domain.TGoods;
import com.ruoyi.common.core.domain.AjaxResult;

import java.util.List;

/**
 * 费用信息Service接口
 *
 * @author ruoyi
 * @date 2020-12-11
 */
public interface ITFeesService {
    /**
     * 查询费用信息
     *
     * @param fId 费用信息ID
     * @return 费用信息
     */
    public TFees selectTFeesById(Long fId);

    /**
     * 查询费用信息列表
     *
     * @param tFees 费用信息
     * @return 费用信息集合
     */
    public List<TFees> selectTFeesList(TFees tFees);

    /**
     * 新增费用信息
     *
     * @param tFees 费用信息
     * @return 结果
     */
    public int insertTFees(TFees tFees);

    /**
     * 修改费用信息
     *
     * @param tFees 费用信息
     * @return 结果
     */
    public AjaxResult updateTFees(TFees tFees);

    /**
     * 批量删除费用信息
     *
     * @param fIds 需要删除的费用信息ID
     * @return 结果
     */
    public AjaxResult deleteTFeesByIds(Long[] fIds);

    /**
     * 删除费用信息信息
     *
     * @param fId 费用信息ID
     * @return 结果
     */
    public int deleteTFeesById(Long fId);

    /**
     *  检验编号唯一
     * @return
     */
    public String checkUFNoUnique(TFees tFees);

    /**
     *  检验编号名称
     * @return
     */
    public String checkUFNnameUnique(TFees tFees);
}
